@@ -5,6 +5,7 @@ from pytest import approx
 
 from hdx.utilities.text import (
     PUNCTUATION_MINUS_BRACKETS,
+    earliest_index,
     get_fraction_str,
     get_matching_text,
     get_matching_text_in_strs,
@@ -28,17 +29,22 @@ class TestText:
     def test_remove_end_characters(self):
         assert remove_end_characters('lalala,.,"') == "lalala"
         assert (
-            remove_end_characters('lalala, .\t/,"', f"{punctuation}{whitespace}")
+            remove_end_characters(
+                'lalala, .\t/,"', f"{punctuation}{whitespace}"
+            )
             == "lalala"
         )
 
     def test_remove_from_end(self):
         result = remove_from_end(
-            TestText.a, ["fast!", "so", "hello", "as"], "Transforming %s -> %s"
+            self.a, ["fast!", "so", "hello", "as"], "Transforming %s -> %s"
         )
         assert result == "The quick brown fox jumped over the lazy dog. It was"
         result = remove_from_end(
-            TestText.a, ["fast!", "so", "hello", "as"], "Transforming %s -> %s", False
+            self.a,
+            ["fast!", "so", "hello", "as"],
+            "Transforming %s -> %s",
+            False,
         )
         assert result == "The quick brown fox jumped over the lazy dog. It w"
 
@@ -46,7 +52,9 @@ class TestText:
         assert remove_string("lala, 01/02/2020 ", "01/02/2020") == "lala "
         assert remove_string("lala,(01/02/2020) ", "01/02/2020") == "lala) "
         assert (
-            remove_string("lala, 01/02/2020 ", "01/02/2020", PUNCTUATION_MINUS_BRACKETS)
+            remove_string(
+                "lala, 01/02/2020 ", "01/02/2020", PUNCTUATION_MINUS_BRACKETS
+            )
             == "lala "
         )
         assert (
@@ -58,36 +66,54 @@ class TestText:
 
     def test_multiple_replace(self):
         result = multiple_replace(
-            TestText.a, {"quick": "slow", "fast": "slow", "lazy": "busy"}
+            self.a, {"quick": "slow", "fast": "slow", "lazy": "busy"}
+        )
+        assert (
+            result
+            == "The slow brown fox jumped over the busy dog. It was so slow!"
         )
-        assert result == "The slow brown fox jumped over the busy dog. It was so slow!"
 
     def test_get_words_in_sentence(self):
-        result = get_words_in_sentence("Korea (Democratic People's Republic of)")
+        result = get_words_in_sentence(
+            "Korea (Democratic People's Republic of)"
+        )
         assert result == ["Korea", "Democratic", "People's", "Republic", "of"]
         result = get_words_in_sentence("Serbia and Kosovo: S/RES/1244 (1999)")
-        assert result == ["Serbia", "and", "Kosovo", "S", "RES", "1244", "1999"]
+        assert result == [
+            "Serbia",
+            "and",
+            "Kosovo",
+            "S",
+            "RES",
+            "1244",
+            "1999",
+        ]
 
     def test_get_matching_text_in_strs(self):
-        result = get_matching_text_in_strs(TestText.a, TestText.b)
+        result = get_matching_text_in_strs(self.a, self.b)
         assert result == []
-        result = get_matching_text_in_strs(TestText.a, TestText.b, match_min_size=10)
+        result = get_matching_text_in_strs(self.a, self.b, match_min_size=10)
         assert result == [" brown fox ", " over the ", ". It was so fast!"]
         result = get_matching_text_in_strs(
-            TestText.a, TestText.b, match_min_size=9, end_characters=".!\r\n"
+            self.a, self.b, match_min_size=9, end_characters=".!\r\n"
         )
-        assert result == ["The quick", " brown fox ", " over the ", " It was so fast!"]
-        result = get_matching_text_in_strs(TestText.a, TestText.c, match_min_size=5)
+        assert result == [
+            "The quick",
+            " brown fox ",
+            " over the ",
+            " It was so fast!",
+        ]
+        result = get_matching_text_in_strs(self.a, self.c, match_min_size=5)
         assert result == [
             "The quick brown fox ",
             "ed over the lazy dog. It was so fast!",
         ]
         result = get_matching_text_in_strs(
-            TestText.a, TestText.c, match_min_size=5, end_characters=".\r\n"
+            self.a, self.c, match_min_size=5, end_characters=".\r\n"
         )
         assert result == ["The quick brown fox ", "ed over the lazy dog."]
         result = get_matching_text_in_strs(
-            TestText.a, TestText.c, match_min_size=5, end_characters=".!\r\n"
+            self.a, self.c, match_min_size=5, end_characters=".!\r\n"
         )
         assert result == [
             "The quick brown fox ",
@@ -95,15 +121,17 @@ class TestText:
         ]
 
     def test_get_matching_text(self):
-        l = [TestText.a, TestText.b, TestText.c]
-        result = get_matching_text(l, match_min_size=10)
+        list_of_text = [self.a, self.b, self.c]
+        result = get_matching_text(list_of_text, match_min_size=10)
         assert result == " brown fox  over the  It was so fast!"
         description = [
             'Internally displaced persons are defined according to the 1998 Guiding Principles (http://www.internal-displacement.org/publications/1998/ocha-guiding-principles-on-internal-displacement) as people or groups of people who have been forced or obliged to flee or to leave their homes or places of habitual residence, in particular as a result of armed conflict, or to avoid the effects of armed conflict, situations of generalized violence, violations of human rights, or natural or human-made disasters and who have not crossed an international border.\n\n"People Displaced" refers to the number of people living in displacement as of the end of each year.\n\nContains data from IDMC\'s [data portal](https://github.com/idmc-labs/IDMC-Platform-API/wiki).',
             'Internally displaced persons are defined according to the 1998 Guiding Principles (http://www.internal-displacement.org/publications/1998/ocha-guiding-principles-on-internal-displacement) as people or groups of people who have been forced or obliged to flee or to leave their homes or places of habitual residence, in particular as a result of armed conflict, or to avoid the effects of armed conflict, situations of generalized violence, violations of human rights, or natural or human-made disasters and who have not crossed an international border.\n\n"New Displacement" refers to the number of new cases or incidents of displacement recorded, rather than the number of people displaced. This is done because people may have been displaced more than once.\n\nContains data from IDMC\'s [data portal](https://github.com/idmc-labs/IDMC-Platform-API/wiki).',
             'Internally displaced persons are defined according to the 1998 Guiding Principles (http://www.internal-displacement.org/publications/1998/ocha-guiding-principles-on-internal-displacement) as people or groups of people who have been forced or obliged to flee or to leave their homes or places of habitual residence, in particular as a result of armed conflict, or to avoid the effects of armed conflict, situations of generalized violence, violations of human rights, or natural or human-made disasters and who have not crossed an international border.\n\n"New Displacement" refers to the number of new cases or incidents of displacement recorded, rather than the number of people displaced. This is done because people may have been displaced more than once.\n\nContains data from IDMC\'s [data portal](https://github.com/idmc-labs/IDMC-Platform-API/wiki).',
         ]
-        result = get_matching_text(description, ignore="\n", end_characters=".!")
+        result = get_matching_text(
+            description, ignore="\n", end_characters=".!"
+        )
         assert (
             result
             == """Internally displaced persons are defined according to the 1998 Guiding Principles (http://www.internal-displacement.org/publications/1998/ocha-guiding-principles-on-internal-displacement) as people or groups of people who have been forced or obliged to flee or to leave their homes or places of habitual residence, in particular as a result of armed conflict, or to avoid the effects of armed conflict, situations of generalized violence, violations of human rights, or natural or human-made disasters and who have not crossed an international border.
@@ -112,8 +140,10 @@ Contains data from IDMC's [data portal](https://github.com/idmc-labs/IDMC-Platfo
         )
 
     def test_get_matching_then_nonmatching_text(self):
-        l = [TestText.a, TestText.b, TestText.c]
-        result = get_matching_then_nonmatching_text(l, match_min_size=10)
+        list_of_str = [self.a, self.b, self.c]
+        result = get_matching_then_nonmatching_text(
+            list_of_str, match_min_size=10
+        )
         assert (
             result
             == " brown fox  over the  It was so fast!The quickjumpedlazy dog.The quickerleaptslower fox.The quickclimbedlazy dog."
@@ -177,3 +207,13 @@ Contains data from IDMC's [data portal](https://github.com/idmc-labs/IDMC-Platfo
         assert get_numeric_if_possible("123,123.45%") == 1231.2345
         assert get_numeric_if_possible("-123,123.45%") == -1231.2345
         assert get_numeric_if_possible("123.123,45%") == 1231.2345
+
+    def test_earliest_index(self):
+        assert earliest_index(self.a, ["fox"]) == 16
+        assert earliest_index(self.a, ["lala"]) is None
+        assert earliest_index(self.a, ["lala", "fox", "haha", "dog"]) == 16
+        assert earliest_index(self.a, ["dog", "lala", "fox", "haha"]) == 16
+        assert (
+            earliest_index(self.a, ["dog", "lala", "fox", "haha", "quick"])
+            == 4
+        )
